#!/usr/bin/env bash

case $1 in
exec)
    echo "mvn -Dexec.executable='echo' -Dexec.args='{project.artifactId}' exec:exec -q"
    mvn -Dexec.executable='echo' -Dexec.args=$1' ${project.artifactId}' exec:exec -q
    ;;
checkstyle)
    echo "mvn checkstyle:checkstyle > check.log"
    mvn checkstyle:checkstyle > check.log
    ;;
dependency)
    echo "mvn dependency:tree > dep.log"
    mvn dependency:tree > dep.log
    ;;
docker)
    echo "mvn clean package -Dmaven.test.skip=true -Pdocker"
    mvn clean package -Dmaven.test.skip=true
    ;;
test)
    echo "mvn clean package -Ptest"
    java -version
    mvn clean package -Dmaven.test.skip=true
    ;;
sonarqube)
    echo "mvn clean verify && sonar-scanner"
    export JAVA_HOME=$JAVA_17_HOME
    export PATH="$JAVA_17_HOME/bin:$PATH"
    java -version

    mvn clean verify sonar:sonar \
    -Dmaven.test.skip=true \
    -Dmaven.compiler.source=8 -Dmaven.compiler.target=8 \
    -Dsonar.plugins.downloadOnlyRequired=true \
    -Dsonar.projectKey=mec \
    -Dsonar.projectName='mec' \
    -Dsonar.host.url=http://82.156.200.45:9000 \
    -Dsonar.login="admin" -Dsonar.password="sonarAdmin"
    ;;
*)
    echo "mvn clean package -Dmaven.test.skip=true -Prelease"
    java -version
    mvn clean package -Dmaven.test.skip=true
    ;;
esac
